@@ -65,7 +65,7 @@ class _UvFileBuilder:
 
     def _enter_path(self, path: Path) -> Path:
         if path.exists():
-            name = tempfile.mktemp(dir=path.parent, prefix=path.name)
+            name = tempfile.mktemp(dir=path.parent, prefix=f"{path.name}.")
             backup = path.rename(name)
 
             @self.stack.callback
@@ -76,7 +76,7 @@ class _UvFileBuilder:
             self.stack.callback(path.unlink, True)
         return path
 
-    def build_uv_lock(self) -> Path:
+    def build_uv_lock(self, include_self: bool = False) -> Path:
         locked_repo = self.locked_repository
         packages: list[dict[str, Any]] = []
         for key in locked_repo.packages:
@@ -89,13 +89,16 @@ class _UvFileBuilder:
             packages.append(self._build_lock_entry(related_packages))
         if name := self.project.name:
             version = self.project.pyproject.metadata.get("version", "0.0.0")
-            this_package = {"name": normalize_name(name), "version": version, "source": {"editable": "."}}
+            this_package = {
+                "name": normalize_name(name),
+                "version": version,
+                "source": {"editable" if include_self else "virtual": "."},
+            }
             dependencies: list[dict[str, Any]] = []
             optional_dependencies: dict[str, list[dict[str, Any]]] = {}
-            this_candidate = self.project.make_self_candidate(True)
             for req in self.requirements:
                 group = req.groups[0]
-                if (dep := self._make_dependency(this_candidate, req)) is None:
+                if (dep := self._make_dependency(None, req)) is None:
                     continue
                 if group == "default":
                     dependencies.append(dep)
@@ -189,9 +192,11 @@ class _UvFileBuilder:
             result["optional-dependencies"] = optional_dependencies
         return result
 
-    def _make_dependency(self, candidate: Candidate, req: Requirement) -> dict[str, Any] | None:
+    def _make_dependency(self, parent: Candidate | None, req: Requirement) -> dict[str, Any] | None:
         locked_repo = self.locked_repository
-        parent_marker = (req.marker or get_marker("")) & (candidate.req.marker or get_marker(""))
+        parent_marker = req.marker or get_marker("")
+        if parent is not None:
+            parent_marker &= parent.req.marker or get_marker("")
         matching_entries = [e for k, e in locked_repo.packages.items() if k[0] == req.key]
 
         def marker_match(marker: Marker | None) -> bool:
